/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.greenseeker;

/**
 * File description enum for Greenseeker sensorfiles
 * This enum describes the columns in a greenseeker sensorfile
 *
 * @author Gerben Feenstra
 */
public enum GreenseekerFileDescriptionNormal {

    /**
     * Record ID
     */
    OBJECTID(0,1,true,java.lang.Double.class),

    /**
     * Part of GPS coordinate
     */
    LATITUDE(1,1,true,java.lang.Double.class),

    /**
     * Part of GPS coordinate
     */
    LONGITUDE(2,1,true,java.lang.Double.class),

    /**
     * Moving speed of vehicle
     */
    SPEED(3,1,true,java.lang.Double.class),

    /**
     * Direction/course
     */
    HEADING(4,1,true,java.lang.Double.class),

    /**
     * Change in height 
     * {@link http://www.cropquest.com/site/page/precisionag_elevation}
     */
    ELEVATION(5,1,true,java.lang.Double.class),

    /**
     * Normalized Difference Vegetation Index, calculated with values of red reflected light (VIS) and Near-infraredlight (NIR)
     * Formula = (VIS - NIR) / (VIS + NIR)
     * Measurement of fotosynthesis of a crop which can be an indication of nitrogen content, depending how large the crop is.
     * Between 0 and 1
     */
    NDVI(6,1,true,java.lang.Double.class),

    /**
     * {@link http://www.ntechindustries.com/lit/gs/DataSheet_Model_500_GS_Sensor.pdf}
     * {@link http://trl.trimble.com/docushare/dsweb/Get/Document-493092/}
     * Vegetation index
     * Default is IRVI (Inverse Ratio Vegetation Index
     * Can also be RVI, NDVI, SA-NDVI: (Soil Adjusted), WDR-NDVI
     */
    VI_2ND(7,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    SENSOR_10(8,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    SENSOR_23(9,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    SENSOR_73(10,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    SENSOR_19(11,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    SENSOR_24(12,1,true,java.lang.Double.class),

    /**
     * TODO: Javadoc
     */
    SENSOR_26(13,1,true,java.lang.Double.class);

    private final int position;
    private final int mandatoryLength;
    private final boolean mandatory;
    private final Class theClass;
    public static final int HEADER_LENGTH = 481; // 672 = Header length Borne
    public static final int RECORD_LENGTH = 211;

    private GreenseekerFileDescriptionNormal(int position, int mandatoryLength, boolean mandatory, Class theClass ){
            this.position = position;
            this.mandatory = mandatory;
            this.mandatoryLength = mandatoryLength;
            this.theClass = theClass;
    }

    public int getPosition() {
            return position;
    }

    public boolean isMandatory() {
            return mandatory;
    }

    public int getMandatoryLength() {
        return mandatoryLength;
    }

    public Class getTheClass() {
        return theClass;
    }
}
